@@ -82,9 +82,19 @@ int parseInetDiagMesg(struct nl_msg *msg, void *arg)
 
 ConnectionMapping::ConnectionMapping()
 {
+    m_running = true;
     m_thread = std::thread(&ConnectionMapping::loop, this);
 }
 
+ConnectionMapping::~ConnectionMapping()
+{
+    m_running = false;
+    if (m_thread.joinable()) {
+        m_thread.join();
+    }
+}
+
+
 ConnectionMapping::PacketResult ConnectionMapping::pidForPacket(const Packet &packet)
 {
     std::lock_guard<std::mutex> lock{m_mutex};
@@ -116,14 +126,6 @@ ConnectionMapping::PacketResult ConnectionMapping::pidForPacket(const Packet &pa
     return result;
 }
 
-void ConnectionMapping::stop()
-{
-    m_running = false;
-    if (m_thread.joinable()) {
-        m_thread.join();
-    }
-}
-
 void ConnectionMapping::loop()
 {
     std::unique_ptr<nl_sock, decltype(&nl_socket_free)> socket{nl_socket_alloc(), nl_socket_free};
@@ -131,8 +133,6 @@ void ConnectionMapping::loop()
     nl_connect(socket.get(), NETLINK_SOCK_DIAG);
     nl_socket_modify_cb(socket.get(), NL_CB_VALID, NL_CB_CUSTOM, &parseInetDiagMesg, this);
 
-    m_running = true;
-
     while (m_running) {
         m_seenAddresses.clear();
         m_seenInodes.clear();
@@ -225,7 +225,7 @@ void ConnectionMapping::parsePid()
             // /proc/PID/fd contains symlinks for each open fd in the process.
             // The symlink target contains information about what the fd is about.
             auto size = readlinkat(dirfd(fdDir), fd->d_name, buffer.data(), 99);
-            buffer[size + 1] = '\0';
+            buffer[size] = '\0';
 
             auto view = std::string_view(buffer.data(), 100);
 
