@@ -1,25 +1,12 @@
 /*
-    Copyright (c) 2019 David Edmundson <davidedmundson@kde.org>
+    SPDX-FileCopyrightText: 2019 David Edmundson <davidedmundson@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "process_attribute.h"
-#include "processes.h"
 #include "cgroup.h"
+#include "processes.h"
 
 #include <QMetaMethod>
 
@@ -35,12 +22,14 @@ public:
     QString m_description;
     qreal m_min = 0;
     qreal m_max = 0;
-    KSysGuard::Unit m_unit = KSysGuard::UnitInvalid; //Both a format hint and implies data type (i.e double/string)
+    KSysGuard::Unit m_unit = KSysGuard::UnitInvalid; // Both a format hint and implies data type (i.e double/string)
 
     QHash<KSysGuard::Process *, QVariant> m_data;
     int m_watchCount = 0;
 
     bool m_defaultVisible = false;
+
+    Processes::UpdateFlags m_updateFlags = Processes::StandardInformation;
 };
 
 ProcessAttribute::ProcessAttribute(const QString &id, QObject *parent)
@@ -140,6 +129,16 @@ void KSysGuard::ProcessAttribute::setVisibleByDefault(bool visible)
     d->m_defaultVisible = visible;
 }
 
+Processes::UpdateFlags ProcessAttribute::requiredUpdateFlags() const
+{
+    return d->m_updateFlags;
+}
+
+void ProcessAttribute::setRequiredUpdateFlags(Processes::UpdateFlags flags)
+{
+    d->m_updateFlags = flags;
+}
+
 QVariant ProcessAttribute::data(KSysGuard::Process *process) const
 {
     return d->m_data.value(process);
@@ -157,7 +156,7 @@ void ProcessAttribute::clearData(KSysGuard::Process *process)
     emit dataChanged(process);
 }
 
-QVariant ProcessAttribute::cgroupData(KSysGuard::CGroup *cgroup, const QVector<KSysGuard::Process*> &groupProcesses) const
+QVariant ProcessAttribute::cgroupData(KSysGuard::CGroup *cgroup, const QVector<KSysGuard::Process *> &groupProcesses) const
 {
     Q_UNUSED(cgroup)
 
