@@ -1,27 +1,14 @@
 /*
-    Copyright (c) 2019 Eike Hein <hein@kde.org>
-    Copyright (C) 2020 Arjen Hiemstra <ahiemstra@heimr.nl>
+    SPDX-FileCopyrightText: 2019 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2020 Arjen Hiemstra <ahiemstra@heimr.nl>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "SensorDataModel.h"
 
-#include <optional>
 #include <chrono>
+#include <optional>
 
 #include <QMetaEnum>
 
@@ -55,6 +42,7 @@ public:
     QHash<QString, SensorInfo> sensorInfos;
     QHash<QString, QVariant> sensorData;
     QVariantMap sensorColors;
+    QVariantMap sensorLabels;
 
     bool usedByQml = false;
     bool componentComplete = false;
@@ -123,12 +111,17 @@ QVariant SensorDataModel::data(const QModelIndex &index, int role) const
     case Unit:
         return info.unit;
     case Name:
-        return info.name;
-    case ShortName:
+        return d->sensorLabels.value(sensor, info.name);
+    case ShortName: {
+        auto it = d->sensorLabels.constFind(sensor);
+        if (it != d->sensorLabels.constEnd()) {
+            return *it;
+        }
         if (info.shortName.isEmpty()) {
             return info.name;
         }
         return info.shortName;
+    }
     case Description:
         return info.description;
     case Minimum:
@@ -145,7 +138,7 @@ QVariant SensorDataModel::data(const QModelIndex &index, int role) const
         }
         break;
     case UpdateInterval:
-        //TODO: Make this dynamic once the backend supports it.
+        // TODO: Make this dynamic once the backend supports it.
         return BackendUpdateInterval;
     default:
         break;
@@ -189,7 +182,7 @@ QVariant SensorDataModel::headerData(int section, Qt::Orientation orientation, i
     case Type:
         return info.variantType;
     case UpdateInterval:
-        //TODO: Make this dynamic once the backend supports it.
+        // TODO: Make this dynamic once the backend supports it.
         return BackendUpdateInterval;
     default:
         break;
@@ -226,7 +219,9 @@ qreal SensorDataModel::minimum() const
         return d->minimum.value();
     }
 
-    auto result = std::min_element(d->sensorInfos.cbegin(), d->sensorInfos.cend(), [](const SensorInfo &first, const SensorInfo &second) { return first.min < second.min; });
+    auto result = std::min_element(d->sensorInfos.cbegin(), d->sensorInfos.cend(), [](const SensorInfo &first, const SensorInfo &second) {
+        return first.min < second.min;
+    });
     d->minimum = (*result).min;
     return d->minimum.value();
 }
@@ -241,7 +236,9 @@ qreal SensorDataModel::maximum() const
         return d->maximum.value();
     }
 
-    auto result = std::max_element(d->sensorInfos.cbegin(), d->sensorInfos.cend(), [](const SensorInfo &first, const SensorInfo &second) { return first.max < second.max; });
+    auto result = std::max_element(d->sensorInfos.cbegin(), d->sensorInfos.cend(), [](const SensorInfo &first, const SensorInfo &second) {
+        return first.max < second.max;
+    });
     d->maximum = (*result).max;
     return d->maximum.value();
 }
@@ -300,7 +297,22 @@ void SensorDataModel::setSensorColors(const QVariantMap &sensorColors)
     }
     d->sensorColors = sensorColors;
     Q_EMIT sensorColorsChanged();
-    Q_EMIT dataChanged(index(0,0), index(rowCount() - 1, columnCount() - 1), {Color});
+    Q_EMIT dataChanged(index(0, 0), index(rowCount() - 1, columnCount() - 1), {Color});
+}
+
+QVariantMap SensorDataModel::sensorLabels() const
+{
+    return d->sensorLabels;
+}
+
+void SensorDataModel::setSensorLabels(const QVariantMap &sensorLabels)
+{
+    if (sensorLabels == d->sensorLabels) {
+        return;
+    }
+    d->sensorLabels = sensorLabels;
+    Q_EMIT sensorLabelsChanged();
+    Q_EMIT dataChanged(index(0, 0), index(rowCount() - 1, columnCount() - 1), {Name, ShortName});
 }
 
 int SensorDataModel::updateRateLimit() const
